#
# HidePasswordPlugin (C) Pointwise, Inc and Mike Eggleston
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details, published at 
# http://www.gnu.org/copyleft/gpl.html
#
# =========================
#
# This is an empty TWiki plugin. Use it as a template
# for your own plugins; see TWiki.TWikiPlugins for details.
#
# Each plugin is a package that contains the subs:
#
#   initPlugin           ( $topic, $web, $user, $installWeb )
#   commonTagsHandler    ( $text, $topic, $web )
#   startRenderingHandler( $text, $web )
#   outsidePREHandler    ( $text )
#   insidePREHandler     ( $text )
#   endRenderingHandler  ( $text )
#
# initPlugin is required, all other are optional. 
# For increased performance, all handlers except initPlugin are
# disabled. To enable a handler remove the leading DISABLE_ from
# the function name.
# 
# NOTE: To interact with TWiki use the official TWiki functions
# in the &TWiki::Func module. Do not reference any functions or
# variables elsewhere in TWiki!!


# =========================
package TWiki::Plugins::HidePasswordPlugin; 	# change the package name!!!

# =========================
use vars qw(
		$web $topic $user $installWeb $VERSION $debug
		$hideChmod $hideChar $hidePath
);

$VERSION = '1.000';

# =========================
sub initPlugin
{
    ( $topic, $web, $user, $installWeb ) = @_;

    &TWiki::Func::writeDebug("- TWiki::Plugins::HidePasswordPlugin::initPlugin is OK") if $debug;

    # check for Plugins.pm versions
	if( $TWiki::Plugins::VERSION < 1 ) {
		&TWiki::Func::writeWarning("Version mismatch between HidePasswordPlugin and Plugins.pm");
		return 0;
	}

    # Get plugin preferences, the variable defined by:     
	$hidePath = &TWiki::Func::getPreferencesValue("HIDEPASSWORDPLUGIN_TWIKIDATAPATH") || '*';
	$hideChmod = &TWiki::Func::getPreferencesValue("HIDEPASSWORDPLUGIN_CHMOD") || 0640;
	$hideChar = &TWiki::Func::getPreferencesValue("HIDEPASSWORDPLUGIN_DISPLAYCHARACHTER") || '*';

	# Get plugin debug flag
	$debug = &TWiki::Func::getPreferencesFlag("HIDEPASSWORDPLUGIN_DEBUG") || 0;

	# Plugin correctly initialized
	&TWiki::Func::writeDebug("- TWiki::Plugins::HidePasswordPlugin::initPlugin( $web.$topic ) is OK")
			if $debug;

	return 1;
}


# =========================
sub commonTagsHandler
{
	### my ( $text, $topic, $web ) = @_;   # do not uncomment, use $_[0], $_[1]... instead

	&TWiki::Func::writeDebug("- HidePasswordPlugin::commonTagsHandler( $_[2].$_[1] )")
			if $debug;

	# This is the place to define customized tags and variables
	# Called by sub handleCommonTags, after %INCLUDE:"..."%
	$_[0] =~ s/%PASSWORD\{([^}]*)\}%/&HidePasswordReturnJunk($1)/geo;
}

# =========================
sub DISABLE_startRenderingHandler
{
### my ( $text, $web ) = @_;   # do not uncomment, use $_[0], $_[1] instead

    &TWiki::Func::writeDebug("- EmptyPlugin::startRenderingHandler( $_[1].$topic )")
			if $debug;

    # This handler is called by getRenderedVersion just before the line loop

    # do custom extension rule, like for example:
    # $_[0] =~ s/old/new/go;
}

# =========================
sub DISABLE_outsidePREHandler
{
### my ( $text ) = @_;   # do not uncomment, use $_[0] instead

	#&TWiki::Func::writeDebug("- EmptyPlugin::outsidePREHandler( $web.$topic )") if $debug;

    # This handler is called by getRenderedVersion, in loop outside of <PRE> tag.
    # This is the place to define customized rendering rules.
    # Note: This is an expensive function to comment out.
    # Consider startRenderingHandler instead
}

# =========================
sub DISABLE_insidePREHandler
{
### my ( $text ) = @_;   # do not uncomment, use $_[0] instead

	#&TWiki::Func::writeDebug("- EmptyPlugin::insidePREHandler( $web.$topic )") if $debug;

    # This handler is called by getRenderedVersion, in loop inside of <PRE> tag.
    # This is the place to define customized rendering rules.
    # Note: This is an expensive function to comment out.
    # Consider startRenderingHandler instead
}

# =========================
sub DISABLE_endRenderingHandler
{
### my ( $text ) = @_;   # do not uncomment, use $_[0] instead

    #&TWiki::Func::writeDebug("- EmptyPlugin::endRenderingHandler( $web.$topic )") if $debug;

    # This handler is called by getRenderedVersion just after the line loop

}

# =========================


sub HidePasswordReturnJunk {
	my ($bugID) = @_;

	# the filesystem changes really slow/stop things
	# need to fix this
	#my $file = "$hidePath/$web/$topic.txt";
	#my @st = stat($file);
	#chmod($hideChmod, $file) unless ($st[2] & 07777) == $hideChmod;

	# simply return a bunch of characters
	return ('<nop>' . ($hideChar x 8));
}

1;
